Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/pyportal_simpletest.py
    :caption: examples/pyportal_simpletest.py
    :linenos:

Internet test
-------------

Example to illustrate the device capability to get json data

.. literalinclude:: ../examples/pyportal_internet_json_fetching.py
    :caption: examples/pyportal_internet_json_fetching.py
    :linenos:

QR Test
-------

This example shows a web address QR in the display

.. literalinclude:: ../examples/pyportal_qrcode_generation.py
    :caption: examples/pyportal_qrcode_generation.py
    :linenos:
